@@ -3,7 +3,7 @@
 #define _LIBGDAMM_VALUE_H
 
 
-/* $Id: value.h 1083 2007-06-20 13:57:08Z murrayc $ */
+/* $Id: value.h 1100 2007-09-28 16:02:13Z murrayc $ */
 // -*- C++ -*- //
 
 /* value.h
@@ -89,6 +89,8 @@ public:
   explicit Value(gshort val);
   
   explicit Value(gushort val);
+
+  explicit Value(gulong val);
   
   explicit Value(const Glib::ustring& val);
   
@@ -195,6 +197,10 @@ public:
   gushort get_ushort() const;
   
   void set(gushort val);
+
+  gulong get_ulong() const;
+  
+  void set(gulong val);
   
   Glib::ustring get_string() const;
   
